| Title: | Visualize and Summarize Repeat-Dose Toxicology Study Results |
|---|---|
| Description: | A 'shiny' app that generates plots and summary tables from repeat-dose toxicology study results to facilitate holistic evaluation of the drug safety of active pharmaceutical ingredients (API) prior to initiation of clinical trials. |
| Authors: | Yousuf Ali [cre, aut], Kevin Snyder [aut], FDA [cph] |
| Maintainer: | Yousuf Ali <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-27 09:15:24 UTC |
| Source: | https://github.com/phuse-org/toxSummary |
Run toxSummary app
toxSummary_app( database_path = NULL, studyid_file = NULL, save_file_path = NULL, where_to_run = "local" )toxSummary_app( database_path = NULL, studyid_file = NULL, save_file_path = NULL, where_to_run = "local" )
database_path |
Optional, character |
studyid_file |
Optional, character |
save_file_path |
optional, character |
where_to_run |
Optional, character |
function run the app.
if(interactive()) { toxSummary_app() }if(interactive()) { toxSummary_app() }